# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Celery settings for the cluster controller.

Do not edit this file.  Instead, put custom settings in a module named
maas_local_celeryconfig.py somewhere on the PYTHONPATH.
"""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
)

str = None

__metaclass__ = type

from datetime import timedelta

import celeryconfig_common
from provisioningserver.utils import import_settings

# Cluster UUID.  Will be overridden by the customized setting in the
# local MAAS Celery config.
CLUSTER_UUID = None

import_settings(celeryconfig_common)

try:
    import maas_local_celeryconfig_cluster
except ImportError:
    pass
else:
    import_settings(maas_local_celeryconfig_cluster)

DHCP_LEASE_UPLOAD_SCHEDULE = timedelta(minutes=1)
REPORT_BOOT_IMAGES_SCHEDULE = timedelta(minutes=5)
PROBE_DHCP_SERVERS_SCHEDULE = timedelta(minutes=1)

CELERYBEAT_SCHEDULE = {
    'unconditional-dhcp-lease-upload': {
        'task': 'provisioningserver.tasks.upload_dhcp_leases',
        'schedule': DHCP_LEASE_UPLOAD_SCHEDULE,
        'options': {
            'queue': CLUSTER_UUID,
            'expires': int(DHCP_LEASE_UPLOAD_SCHEDULE.total_seconds()),
        },
    },
    'report-boot-images': {
        'task': 'provisioningserver.tasks.report_boot_images',
        'schedule': REPORT_BOOT_IMAGES_SCHEDULE,
        'options': {
            'queue': CLUSTER_UUID,
            'expires': int(REPORT_BOOT_IMAGES_SCHEDULE.total_seconds()),
        },
    },
    'probe-dhcp-servers': {
        'task': 'provisioningserver.tasks.periodic_probe_dhcp',
        'schedule': PROBE_DHCP_SERVERS_SCHEDULE,
        'options': {
            'queue': CLUSTER_UUID,
            'expires': int(PROBE_DHCP_SERVERS_SCHEDULE.total_seconds()),
        },
    },
}
